BFGraph: RepHash Class Reference

BFGraph

Public Member Functions
RepHash Class Reference

## Public Member Functions
| RepHash (int _k)
void | seed (int s)
void | fastleftshiftk (uint64_t &x)
void | fastrightshiftk (uint64_t &x)
void | fastleftshift1 (uint64_t &x)
void | fastrightshift1 (uint64_t &x)
uint64_t | hash () const
void | init (const char *_s)
void | update (const unsigned char out, const unsigned char in)
void | extendFW (const unsigned char fw)
void | increaseK ()
void | setK (int _k)
void | extendBW (const unsigned char bw)
uint64_t | charmask (unsigned char x)
uint64_t | twinmask (unsigned char x)

The documentation for this class was generated from the following file:

- src/RepHash.hpp